@@ -96,7 +96,7 @@ def print_lease(lease: Lease, fmt: str):
     elif fmt == "cols":
         fields = [lease.principal, timestamp(), lease.id]
         width = max(map(len, fields)) + 4
-        print("{:{w}}{:{w}}{:{w}}".format("PRINCIPAL", "CREATED", "ID", w=width))
+        print(f"{'PRINCIPAL':{width}}{'CREATED':{width}}{'ID':{width}}")
         print("{:{w}}{:{w}}{:{w}}".format(*fields, w=width))
 
 
@@ -150,16 +150,15 @@ def run():
 
     args = parser.parse_args()
 
-    lock = load_lock(args.resource, args.config)
-
-    cmd = args.cmd
-    if cmd == "acquire":
-        acquire(lock, args.ttl)
-    elif cmd == "release":
-        lock.release(args.lease_id)
-    elif cmd == "renew":
-        renew(lock, args.lease_id, args.ttl)
-    elif cmd == "current":
-        current(lock, args.format)
-    elif cmd == "is-held":
-        is_held(lock, args.lease_id)
+    with load_lock(args.resource, args.config) as lock:
+        cmd = args.cmd
+        if cmd == "acquire":
+            acquire(lock, args.ttl)
+        elif cmd == "release":
+            lock.release(args.lease_id)
+        elif cmd == "renew":
+            renew(lock, args.lease_id, args.ttl)
+        elif cmd == "current":
+            current(lock, args.format)
+        elif cmd == "is-held":
+            is_held(lock, args.lease_id)
