@@ -130,6 +130,12 @@ class StormLock:
         """
         return self._backend.is_current(self._resource, lease_id)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self._backend.__exit__(self, exc_type, exc_value, traceback)
+
 
 _SEARCH_PATHS = [
     "./.stormlock.cfg",
@@ -174,7 +180,7 @@ def _find_conf_file() -> str:
     for path in _SEARCH_PATHS:
         if os.path.isfile(path):
             return path
-    raise Exception("Unable to find stormlock configuration file")
+    raise RuntimeError("Unable to find stormlock configuration file")
 
 
 def _get_cfg_value(cfg: ConfigParser, section: str, name: str) -> str:
